@@ -1,10 +1,16 @@
 import os
 import toml
-import datetime as dt
 import pyhectiqlab.ops as ops
+from typing import Optional
 
 from pathlib import Path
 
+"""
+Envs vars:
+HECTIQLAB_X_SECRET_KEY: Secret api key. If set, this key is used.
+HECTIQLAB_PROFILE: Profile name
+HECTIQLAB_CREDENTIALS: Path to custom credential files
+"""
 class AuthProvider(object):
     """
     Class used to handle oAuth
@@ -23,12 +29,14 @@ class AuthProvider(object):
             self.profile = name
 
     def is_logged(self):
+        if os.getenv("HECTIQLAB_X_SECRET_KEY"): 
+            return True
         if self.secret_api_key is not None:
             return True
         return False
     
-    def fetch_secret_api_token(self, username:str, password:str):
-        res = ops.fetch_secret_api_token(username, password)
+    def fetch_secret_api_token(self, username:str, password:str, name: Optional[str] = None):
+        res = ops.fetch_secret_api_token(name, username, password)
         if res.get('status_code')!=200:
             return False, None
         self._update_local_api_keys(username, username, res.get('secret_api_key'), res.get('secret_api_key_uuid'))
@@ -39,6 +47,8 @@ class AuthProvider(object):
 
     @property
     def secret_api_key(self):
+        if os.getenv("HECTIQLAB_X_SECRET_KEY"):
+            return os.getenv("HECTIQLAB_X_SECRET_KEY")
         if self.profile in self.profiles:
             if 'secret_api_key' in self.profiles[self.profile]:
                 return self.profiles[self.profile]["secret_api_key"]
