@@ -96,6 +96,13 @@ def fetch_run(path, project_path, token):
                 token=token)
     return res
 
+def rename_run(new_name, path, project_path, token):
+    res = lab_request(path=f"/{project_path}/runs/{path}/rename", 
+                request_type="POST", 
+                body_args=dict(name=new_name),
+                token=token)
+    return res
+    
 def fetch_run_packages(path, project_path, token):
     res = lab_request(path=f"/{project_path}/runs/{path}/packages", 
                 request_type="GET", 
