@@ -21,6 +21,7 @@ from functools import partial
 from typing import Optional, Union
 import tempfile
 import logging
+from mnemonic import Mnemonic
 import traceback
 logger = logging.getLogger("pyhectiqlab")
 import shutil
@@ -38,7 +39,12 @@ class Run():
                 are unexecuted.
         """
         assert project, "The arugment `project` is required."
-        assert name or path, "One of `name` or `path` must be specified."
+        self._is_untitled = False
+        if name==None and path==None:
+            mnemo = Mnemonic("english")
+            name = "Untitled run - " + " ".join(mnemo.generate().split(" ")[:3])
+            self._is_untitled = True
+            print(f"Your run is untitled. Temporary name is {name}")
         self._read_only = read_only
         if self._preflight():
             if path:
@@ -46,6 +52,8 @@ class Run():
             else:
                 self.run_view = self.events_manager.add_event('create_run', args=(name, project), auth=True, async_method=False)
             self._setup_run()
+        if self._is_untitled:
+            self.add_tag("untitled")
 
     @classmethod
     def existing(cls, path: str, project: str, read_only: bool = False):
@@ -64,7 +72,7 @@ class Run():
         """
         self.events_manager = EventsManager(self._read_only)
         self.events_manager.compare_python_version()
-        
+
         self.log_streams = {}
         self._stream_exception()
 
@@ -116,6 +124,7 @@ class Run():
         self.logs_buffer = Buffer(push_method=self._push_logs)
         self.add_log_stream("pyhectiqlab", level=logging.INFO)
         self.tmp_artifacts = None
+        self.metrics_group = None
 
     def user_is_not_logged(self):
         print("User not authentificated. Use `hectiqlab add-profile` in command line.")
@@ -382,6 +391,18 @@ class Run():
         assert aggr in ['none', 'sum', 'max', 'mean']
         self.metrics_manager.set_aggr(aggr)
 
+    @write_method
+    @action_method
+    def set_metrics_group(self, group: str):
+        """Add a group to all future pushed metrics.
+        For instance,
+        ```python
+        self.set_metrics_group("w=2")
+        self.add_metrics("sin(wx)", step=1, value=np.sin(2)) # Metrics will be "sin(wx)::w=2"
+        ```
+        """
+        self.metrics_group = group
+
     @write_method
     @action_method
     def add_metrics(self, key: 'str', step: float, value: float):
@@ -393,6 +414,8 @@ class Run():
         value [float]. If tensor, is casted to float.
         step [float]: Step
         """
+        if self.metrics_group:
+            key = key + "::" + self.metrics_group
         self.metrics_manager.add(key, float(value), step)
 
     @write_method
@@ -479,6 +502,8 @@ class Run():
         """
         args = (self._id, self._project_path, "completed")
         self.events_manager.add_event("set_run_status", args)
+        if self._is_untitled:
+            print("Your run is untitled. Consider using `run.rename(name)` to fix it.")
         
     @write_method
     @action_method
@@ -529,6 +554,22 @@ class Run():
         args = (self._id, self._project_path, content)
         self.events_manager.add_event("set_paper", args)
 
+    @write_method
+    @action_method
+    def rename(self, name: str):
+        """Rename the run
+        """
+        args = (name, self._id, self._project_path)
+        updated_view = self.events_manager.add_event("rename_run", args, async_method=False)
+        try:
+            if updated_view.get("status_code")==200:
+                self.run_view = updated_view
+                self._is_untitled = False
+            else:
+                print(updated_view.get("detail"))
+        except:
+            print("Rename operation failed. Please use the web application.")
+
     @write_method
     @action_method
     def clear_logs(self):
