@@ -4,16 +4,16 @@ class RepeatedTimer(threading.Thread):
     def __init__(self, method, delay):
         super().__init__()
         self.daemon = True
-        self._stop = threading.Event()
+        self._stopper = threading.Event()
         self.delay = delay
         self.method = method
 
     def run(self):
-        while not self._stop.wait(self.delay):
+        while not self._stopper.wait(self.delay):
             self.method()
             
     def stopped(self):
-        return self._stop.isSet()
+        return self._stopper.isSet()
 
     def stop(self):
-        self._stop.set()
\ No newline at end of file
+        self._stopper.set()
\ No newline at end of file
